tdub.art
--------

A module for art (plots)

.. currentmodule:: tdub.art

Function Summary
^^^^^^^^^^^^^^^^

.. autosummary::

   canvas_from_counts
   draw_atlas_label
   draw_impact_barh
   draw_uncertainty_bands
   legend_last_to_first
   setup_tdub_style

Reference
^^^^^^^^^

.. autofunction:: canvas_from_counts
.. autofunction:: draw_atlas_label
.. autofunction:: draw_impact_barh
.. autofunction:: draw_uncertainty_bands
.. autofunction:: legend_last_to_first
.. autofunction:: setup_tdub_style
